app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("testOnlyRLog")

app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runSpotIter = "click")
app$setInputs(rLogMode = TRUE)
app$setInputs(runCreateDOE = "click")
app$setInputs(evaluateData = "click")
app$setInputs(runSpotIter = "click")
app$setInputs(rLogMode = FALSE)
app$setInputs(proposeNewPoint = "click")
app$setInputs(evaluateData = "click")
app$snapshot(list(output = "resultTable"))
app$setInputs(tabs = "exports")
app$snapshot(list(output = "rLog"))
